==> netdata-go-plugins-0.41.2.tar.gz: go.d.plugin-0.41.2/modules/httpcheck/charts.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package httpcheck

import (
	"github.com/netdata/go.d.plugin/agent/module"
)

const (
	prioResponseTime = module.Priority + iota
	prioResponseLength
	prioResponseStatus
	prioResponseInStatusDuration
)

var charts = module.Charts{
	responseTimeChart.Copy(),
	responseLengthChart.Copy(),
	responseStatusChart.Copy(),
	responseInStatusDurationChart.Copy(),
}

var responseTimeChart = module.Chart{
	ID:       "response_time",
	Title:    "HTTP Response Time",
	Units:    "ms",
	Fam:      "response",
	Ctx:      "httpcheck.response_time",
	Priority: prioResponseTime,
	Dims: module.Dims{
		{ID: "time"},
	},
}

var responseLengthChart = module.Chart{
	ID:       "response_length",
	Title:    "HTTP Response Body Length",
	Units:    "characters",
	Fam:      "response",
	Ctx:      "httpcheck.response_length",
	Priority: prioResponseLength,
	Dims: module.Dims{
		{ID: "length"},
	},
}

var responseStatusChart = module.Chart{
	ID:       "request_status",
	Title:    "HTTP Check Status",
	Units:    "boolean",
	Fam:      "status",
	Ctx:      "httpcheck.status",
	Priority: prioResponseStatus,
	Dims: module.Dims{
		{ID: "success"},
		{ID: "no_connection"},
		{ID: "timeout"},
		{ID: "bad_content"},
		{ID: "bad_status"},
		//{ID: "dns_lookup_error", Name: "dns lookup error"},
		//{ID: "address_parse_error", Name: "address parse error"},
		//{ID: "redirect_error", Name: "redirect error"},
		//{ID: "body_read_error", Name: "body read error"},
	},
}

var responseInStatusDurationChart = module.Chart{
	ID:       "current_state_duration",
	Title:    "HTTP Current State Duration",
	Units:    "seconds",
	Fam:      "status",
	Ctx:      "httpcheck.in_state",
	Priority: prioResponseInStatusDuration,
	Dims: module.Dims{
		{ID: "in_state", Name: "time"},
	},
}

==> netdata-go-plugins-0.56.0.tar.gz: go.d.plugin-0.56.0/modules/httpcheck/charts.go <==
// SPDX-License-Identifier: GPL-3.0-or-later

package httpcheck

import (
	"github.com/netdata/go.d.plugin/agent/module"
)

const (
	prioResponseTime = module.Priority + iota
	prioResponseLength
	prioResponseStatus
	prioResponseInStatusDuration
)

var httpCheckCharts = module.Charts{
	responseTimeChart.Copy(),
	responseLengthChart.Copy(),
	responseStatusChart.Copy(),
	responseInStatusDurationChart.Copy(),
}

var responseTimeChart = module.Chart{
	ID:       "response_time",
	Title:    "HTTP Response Time",
	Units:    "ms",
	Fam:      "response",
	Ctx:      "httpcheck.response_time",
	Priority: prioResponseTime,
	Dims: module.Dims{
		{ID: "time"},
	},
}

var responseLengthChart = module.Chart{
	ID:       "response_length",
	Title:    "HTTP Response Body Length",
	Units:    "characters",
	Fam:      "response",
	Ctx:      "httpcheck.response_length",
	Priority: prioResponseLength,
	Dims: module.Dims{
		{ID: "length"},
	},
}

var responseStatusChart = module.Chart{
	ID:       "request_status",
	Title:    "HTTP Check Status",
	Units:    "boolean",
	Fam:      "status",
	Ctx:      "httpcheck.status",
	Priority: prioResponseStatus,
	Dims: module.Dims{
		{ID: "success"},
		{ID: "no_connection"},
		{ID: "timeout"},
		{ID: "bad_content"},
		{ID: "bad_status"},
	},
}

var responseInStatusDurationChart = module.Chart{
	ID:       "current_state_duration",
	Title:    "HTTP Current State Duration",
	Units:    "seconds",
	Fam:      "status",
	Ctx:      "httpcheck.in_state",
	Priority: prioResponseInStatusDuration,
	Dims: module.Dims{
		{ID: "in_state", Name: "time"},
	},
}
